==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/DataSourceConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property eventLogs Windows event logs configuration.
 * @property perfCounters Performance counter configuration
 * @property providers ETW providers configuration
 */
public data class DataSourceConfigurationArgs(
    public val eventLogs: Output<List<EventLogConfigurationArgs>>? = null,
    public val perfCounters: Output<List<PerformanceCounterConfigurationArgs>>? = null,
    public val providers: Output<List<EtwProviderConfigurationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs =
        com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs.builder()
            .eventLogs(
                eventLogs?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .perfCounters(
                perfCounters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .providers(
                providers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataSourceConfigurationArgs].
 */
@PulumiTagMarker
public class DataSourceConfigurationArgsBuilder internal constructor() {
    private var eventLogs: Output<List<EventLogConfigurationArgs>>? = null

    private var perfCounters: Output<List<PerformanceCounterConfigurationArgs>>? = null

    private var providers: Output<List<EtwProviderConfigurationArgs>>? = null

    /**
     * @param value Windows event logs configuration.
     */
    @JvmName("thfbwcqqptrwrdtm")
    public suspend fun eventLogs(`value`: Output<List<EventLogConfigurationArgs>>) {
        this.eventLogs = value
    }

    @JvmName("jarbdcytmvuvinfv")
    public suspend fun eventLogs(vararg values: Output<EventLogConfigurationArgs>) {
        this.eventLogs = Output.all(values.asList())
    }

    /**
     * @param values Windows event logs configuration.
     */
    @JvmName("ardmmxydkqvinyyo")
    public suspend fun eventLogs(values: List<Output<EventLogConfigurationArgs>>) {
        this.eventLogs = Output.all(values)
    }

    /**
     * @param value Performance counter configuration
     */
    @JvmName("tdhjbnbsdteffdma")
    public suspend fun perfCounters(`value`: Output<List<PerformanceCounterConfigurationArgs>>) {
        this.perfCounters = value
    }

    @JvmName("bsdclgbadmyrocxm")
    public suspend fun perfCounters(vararg values: Output<PerformanceCounterConfigurationArgs>) {
        this.perfCounters = Output.all(values.asList())
    }

    /**
     * @param values Performance counter configuration
     */
    @JvmName("lbhbuonpabudueso")
    public suspend fun perfCounters(values: List<Output<PerformanceCounterConfigurationArgs>>) {
        this.perfCounters = Output.all(values)
    }

    /**
     * @param value ETW providers configuration
     */
    @JvmName("qrdyqyaeaayslsqx")
    public suspend fun providers(`value`: Output<List<EtwProviderConfigurationArgs>>) {
        this.providers = value
    }

    @JvmName("owaljulgwbawdxcg")
    public suspend fun providers(vararg values: Output<EtwProviderConfigurationArgs>) {
        this.providers = Output.all(values.asList())
    }

    /**
     * @param values ETW providers configuration
     */
    @JvmName("ubxrrqfdutvjxcia")
    public suspend fun providers(values: List<Output<EtwProviderConfigurationArgs>>) {
        this.providers = Output.all(values)
    }

    /**
     * @param value Windows event logs configuration.
     */
    @JvmName("pcqfeifwrtptjdmx")
    public suspend fun eventLogs(`value`: List<EventLogConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("gkryktjwolmwavvw")
    public suspend
    fun eventLogs(argument: List<suspend EventLogConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EventLogConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("choghobxijyhevrv")
    public suspend fun eventLogs(
        vararg
        argument: suspend EventLogConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EventLogConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("agafkkrlninbnngn")
    public suspend fun eventLogs(argument: suspend EventLogConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EventLogConfigurationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param values Windows event logs configuration.
     */
    @JvmName("eukhnaqgtcsirhep")
    public suspend fun eventLogs(vararg values: EventLogConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventLogs = mapped
    }

    /**
     * @param value Performance counter configuration
     */
    @JvmName("gekgsdmroylngill")
    public suspend fun perfCounters(`value`: List<PerformanceCounterConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("otaqxrcbeiyuddhh")
    public suspend
    fun perfCounters(argument: List<suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PerformanceCounterConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("dwbxbgtegswygojs")
    public suspend fun perfCounters(
        vararg
        argument: suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            PerformanceCounterConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("ikusqqhnqgyalsrd")
    public suspend
    fun perfCounters(argument: suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            PerformanceCounterConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param values Performance counter configuration
     */
    @JvmName("uajissqltewslixd")
    public suspend fun perfCounters(vararg values: PerformanceCounterConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.perfCounters = mapped
    }

    /**
     * @param value ETW providers configuration
     */
    @JvmName("qrulunbejjpyxfty")
    public suspend fun providers(`value`: List<EtwProviderConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("qfvaeeqxnvwvxxyo")
    public suspend
    fun providers(argument: List<suspend EtwProviderConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EtwProviderConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("jqkvwfawwrlsrtia")
    public suspend fun providers(
        vararg
        argument: suspend EtwProviderConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EtwProviderConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("meuprcaoefpknarb")
    public suspend fun providers(argument: suspend EtwProviderConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            EtwProviderConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param values ETW providers configuration
     */
    @JvmName("hoknsxlbmthhdacs")
    public suspend fun providers(vararg values: EtwProviderConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.providers = mapped
    }

    internal fun build(): DataSourceConfigurationArgs = DataSourceConfigurationArgs(
        eventLogs = eventLogs,
        perfCounters = perfCounters,
        providers = providers,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/DataSourceConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property eventLogs Windows event logs configuration.
 * @property perfCounters Performance counter configuration
 * @property providers ETW providers configuration
 */
public data class DataSourceConfigurationArgs(
    public val eventLogs: Output<List<EventLogConfigurationArgs>>? = null,
    public val perfCounters: Output<List<PerformanceCounterConfigurationArgs>>? = null,
    public val providers: Output<List<EtwProviderConfigurationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs =
        com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs.builder()
            .eventLogs(
                eventLogs?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .perfCounters(
                perfCounters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .providers(
                providers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataSourceConfigurationArgs].
 */
@PulumiTagMarker
public class DataSourceConfigurationArgsBuilder internal constructor() {
    private var eventLogs: Output<List<EventLogConfigurationArgs>>? = null

    private var perfCounters: Output<List<PerformanceCounterConfigurationArgs>>? = null

    private var providers: Output<List<EtwProviderConfigurationArgs>>? = null

    /**
     * @param value Windows event logs configuration.
     */
    @JvmName("ubpnhwkjqvxlclcm")
    public suspend fun eventLogs(`value`: Output<List<EventLogConfigurationArgs>>) {
        this.eventLogs = value
    }

    @JvmName("kkcnxixahopwwbid")
    public suspend fun eventLogs(vararg values: Output<EventLogConfigurationArgs>) {
        this.eventLogs = Output.all(values.asList())
    }

    /**
     * @param values Windows event logs configuration.
     */
    @JvmName("djhhdswlmxwcmuwi")
    public suspend fun eventLogs(values: List<Output<EventLogConfigurationArgs>>) {
        this.eventLogs = Output.all(values)
    }

    /**
     * @param value Performance counter configuration
     */
    @JvmName("xfaodplgojycqjbu")
    public suspend fun perfCounters(`value`: Output<List<PerformanceCounterConfigurationArgs>>) {
        this.perfCounters = value
    }

    @JvmName("ygjigvunumdthwkw")
    public suspend fun perfCounters(vararg values: Output<PerformanceCounterConfigurationArgs>) {
        this.perfCounters = Output.all(values.asList())
    }

    /**
     * @param values Performance counter configuration
     */
    @JvmName("vladdcorehjuonfg")
    public suspend fun perfCounters(values: List<Output<PerformanceCounterConfigurationArgs>>) {
        this.perfCounters = Output.all(values)
    }

    /**
     * @param value ETW providers configuration
     */
    @JvmName("ykmaixsqrxiarlnv")
    public suspend fun providers(`value`: Output<List<EtwProviderConfigurationArgs>>) {
        this.providers = value
    }

    @JvmName("ndjnrxybjwgvjnbw")
    public suspend fun providers(vararg values: Output<EtwProviderConfigurationArgs>) {
        this.providers = Output.all(values.asList())
    }

    /**
     * @param values ETW providers configuration
     */
    @JvmName("mkwopibnapytkoer")
    public suspend fun providers(values: List<Output<EtwProviderConfigurationArgs>>) {
        this.providers = Output.all(values)
    }

    /**
     * @param value Windows event logs configuration.
     */
    @JvmName("iodynldwmxwpnwnw")
    public suspend fun eventLogs(`value`: List<EventLogConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("mcplnrmcsdprqryd")
    public suspend
    fun eventLogs(argument: List<suspend EventLogConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EventLogConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("hwakuocuyehmyrpj")
    public suspend fun eventLogs(
        vararg
        argument: suspend EventLogConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EventLogConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("twpjltdmtubptkjv")
    public suspend fun eventLogs(argument: suspend EventLogConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EventLogConfigurationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param values Windows event logs configuration.
     */
    @JvmName("xhaakxdrjfxvuycv")
    public suspend fun eventLogs(vararg values: EventLogConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventLogs = mapped
    }

    /**
     * @param value Performance counter configuration
     */
    @JvmName("islsirymhhofvvkt")
    public suspend fun perfCounters(`value`: List<PerformanceCounterConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("finadyerbxgylwdl")
    public suspend
    fun perfCounters(argument: List<suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PerformanceCounterConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("rcnjqyhydojjtqlq")
    public suspend fun perfCounters(
        vararg
        argument: suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            PerformanceCounterConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("nnlsqveyirvopmic")
    public suspend
    fun perfCounters(argument: suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            PerformanceCounterConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param values Performance counter configuration
     */
    @JvmName("djohthrcxdmkknwb")
    public suspend fun perfCounters(vararg values: PerformanceCounterConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.perfCounters = mapped
    }

    /**
     * @param value ETW providers configuration
     */
    @JvmName("kbdxypeshrypgjam")
    public suspend fun providers(`value`: List<EtwProviderConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("diumvmtkuiopbpmw")
    public suspend
    fun providers(argument: List<suspend EtwProviderConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EtwProviderConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("ncdsodcfhkmxjqga")
    public suspend fun providers(
        vararg
        argument: suspend EtwProviderConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EtwProviderConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("xxbotlakyqyvsglg")
    public suspend fun providers(argument: suspend EtwProviderConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            EtwProviderConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param values ETW providers configuration
     */
    @JvmName("dwokubosbjcvolfw")
    public suspend fun providers(vararg values: EtwProviderConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.providers = mapped
    }

    internal fun build(): DataSourceConfigurationArgs = DataSourceConfigurationArgs(
        eventLogs = eventLogs,
        perfCounters = perfCounters,
        providers = providers,
    )
}
